@@ -306,7 +306,7 @@ int main(int argc, char **argv) {
 		printf("\n");
 		printf("Output:\n");
 		printf(" -m, --mrtg         display output in MRTG compatible format.\n");
-		printf(" -d, --data=VARS    comma-seperated list of variables to output in MRTG\n");
+		printf(" -d, --data=VARS    comma-separated list of variables to output in MRTG\n");
 		printf("                    (or compatible) format.  See possible values below.\n");
 		printf("                    Percentages are rounded, times are in milliseconds.\n");
 		printf(" -D, --delimiter=C  character to use as delimiter in MRTG output mode.\n");
@@ -318,7 +318,7 @@ int main(int argc, char **argv) {
 		printf(" STATUSFILEAGE        string with age of status data file.\n");
 		printf(" STATUSFILEAGETT      string with age of status data file (time_t format).\n");
 		printf(" NAGIOSVERSION        string with Nagios version.\n");
-		printf(" NAGIOSPID            pid number of Nagios deamon.\n");
+		printf(" NAGIOSPID            pid number of Nagios daemon.\n");
 		printf(" NAGIOSVERPID         string with Nagios version and PID.\n");
 		printf(" TOTCMDBUF            total number of external command buffer slots available.\n");
 		printf(" USEDCMDBUF           number of external command buffer slots currently in use.\n");
@@ -329,7 +329,7 @@ int main(int argc, char **argv) {
 		printf(" NUMSVCWARN           number of services WARNING.\n");
 		printf(" NUMSVCUNKN           number of services UNKNOWN.\n");
 		printf(" NUMSVCCRIT           number of services CRITICAL.\n");
-		printf(" NUMSVCPROB           number of service problems (WARNING, UNKNOWN or CRITIAL).\n");
+		printf(" NUMSVCPROB           number of service problems (WARNING, UNKNOWN or CRITICAL).\n");
 		printf(" NUMSVCCHECKED        number of services that have been checked since start.\n");
 		printf(" NUMSVCSCHEDULED      number of services that are currently scheduled to be checked.\n");
 		printf(" NUMSVCFLAPPING       number of services that are currently flapping.\n");
@@ -358,18 +358,18 @@ int main(int argc, char **argv) {
 		printf(" xxxPSVHSTLAT         MIN/MAX/AVG passive host check latency (ms).\n");
 		printf(" xxxPSVHSTPSC         MIN/MAX/AVG passive host check %% state change.\n");
 		printf(" xxxHSTPSC            MIN/MAX/AVG host check %% state change.\n");
-		printf(" NUMACTHSTCHECKSxM    number of total active host checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMOACTHSTCHECKSxM   number of on-demand active host checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMCACHEDHSTCHECKSxM number of cached host checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMSACTHSTCHECKSxM   number of scheduled active host checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMPARHSTCHECKSxM    number of parallel host checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMSERHSTCHECKSxM    number of serial host checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMPSVHSTCHECKSxM    number of passive host checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMACTSVCCHECKSxM    number of total active service checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMOACTSVCCHECKSxM   number of on-demand active service checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMCACHEDSVCCHECKSxM number of cached service checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMSACTSVCCHECKSxM   number of scheduled active service checks occuring in last 1/5/15 minutes.\n");
-		printf(" NUMPSVSVCCHECKSxM    number of passive service checks occuring in last 1/5/15 minutes.\n");
+		printf(" NUMACTHSTCHECKSxM    number of total active host checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMOACTHSTCHECKSxM   number of on-demand active host checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMCACHEDHSTCHECKSxM number of cached host checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMSACTHSTCHECKSxM   number of scheduled active host checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMPARHSTCHECKSxM    number of parallel host checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMSERHSTCHECKSxM    number of serial host checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMPSVHSTCHECKSxM    number of passive host checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMACTSVCCHECKSxM    number of total active service checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMOACTSVCCHECKSxM   number of on-demand active service checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMCACHEDSVCCHECKSxM number of cached service checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMSACTSVCCHECKSxM   number of scheduled active service checks occurring in last 1/5/15 minutes.\n");
+		printf(" NUMPSVSVCCHECKSxM    number of passive service checks occurring in last 1/5/15 minutes.\n");
 		printf(" NUMEXTCMDSxM         number of external commands processed in last 1/5/15 minutes.\n");
 
 		printf("\n");
