@@ -7,6 +7,10 @@
  *
  * This code uses the eventbroker api to get its data, which means
  * we're finally eating our own dogfood in that respect.
+ *
+ * Note: Disabled by default as of 4.4.0
+ * ./configure --enable-nerd
+ * to enable!
  */
 
 #define _GNU_SOURCE 1
@@ -22,6 +26,8 @@
 #include "include/nebmodules.h"
 #include "include/nebstructs.h"
 
+#ifdef ENABLE_NERD
+
 struct nerd_channel {
 	const char *name; /* name of this channel */
 	const char *description; /* user-presentable string to document the purpouse of this channel */
@@ -493,3 +499,5 @@ int nerd_init(void)
 	logit(NSLOG_INFO_MESSAGE, TRUE, "nerd: Fully initialized and ready to rock!\n");
 	return 0;
 }
+
+#endif
\ No newline at end of file
