@@ -139,7 +139,7 @@ int main(int argc, char **argv) {
 	init_shared_cfg_vars(1);
 
 	/* read the CGI configuration file */
-	result = read_cgi_config_file(get_cgi_config_location());
+	result = read_cgi_config_file(get_cgi_config_location(), NULL);
 	if(result == ERROR) {
 		document_header();
 		return ERROR;
@@ -215,7 +215,7 @@ int process_cgivars(void) {
 
 	variables = getcgivars();
 
-	for(x = 0; variables[x] != NULL; x++) {
+	for(x = 0; variables[x]; x++) {
 
 		/* do some basic length checking on the variable identifier to prevent buffer overflows */
 		if(strlen(variables[x]) >= MAX_INPUT_BUFFER - 1) {
@@ -907,14 +907,17 @@ void draw_host(host *temp_host) {
 	if(temp_host == NULL)
 		return;
 
+	/* see if user is authorized to view this host  */
+	if(is_authorized_for_host(temp_host, &current_authdata) == FALSE)
+		return;
+
 	/* make sure we have the coordinates */
 	if(temp_host->have_3d_coords == FALSE)
 		return;
-	else {
-		x = temp_host->x_3d;
-		y = temp_host->y_3d;
-		z = temp_host->z_3d;
-		}
+
+	x = temp_host->x_3d;
+	y = temp_host->y_3d;
+	z = temp_host->z_3d;
 
 	/* make the host name safe for embedding in VRML */
 	vrml_safe_hostname = (char *)strdup(temp_host->name);
@@ -926,10 +929,6 @@ void draw_host(host *temp_host) {
 			vrml_safe_hostname[a] = '_';
 		}
 
-	/* see if user is authorized to view this host  */
-	if(is_authorized_for_host(temp_host, &current_authdata) == FALSE)
-		return;
-
 	/* get the status of the host */
 	temp_hoststatus = find_hoststatus(temp_host->name);
 
