@@ -119,6 +119,9 @@ extern int host_freshness_check_interval;
 extern int auto_rescheduling_interval;
 extern int auto_rescheduling_window;
 
+extern int enable_soft_host_recovery;
+extern int enable_soft_service_recovery;
+
 extern int check_orphaned_services;
 extern int check_orphaned_hosts;
 extern int check_service_freshness;
@@ -188,6 +191,10 @@ extern unsigned long max_debug_file_size;
 extern int allow_empty_hostgroup_assignment;
 
 extern int host_down_disable_service_checks;
+extern int service_skip_check_dependency_status;
+extern int service_skip_check_parent_status;
+extern int service_skip_check_host_down_status;
+extern int host_skip_check_dependency_status;
 
 extern time_t last_program_stop;
 extern time_t event_start;
@@ -428,13 +435,6 @@ NAGIOS_BEGIN_DECL
 		retry_check_window(o) : \
 		normal_check_window(o))
 
-/** Nerd subscription type */
-struct nerd_subscription {
-	int sd;
-	struct nerd_channel *chan;
-	char *format; /* requested format (macro string) for this subscription */
-};
-
 /******************** FUNCTIONS **********************/
 extern int set_loadctl_options(char *opts, unsigned int len);
 
@@ -445,6 +445,15 @@ extern const char *state_type_name(int state_type);
 extern const char *check_type_name(int check_type);
 extern const char *check_result_source(check_result *cr);
 
+#ifdef ENABLE_NERD
+
+/** Nerd subscription type */
+struct nerd_subscription {
+	int sd;
+	struct nerd_channel *chan;
+	char *format; /* requested format (macro string) for this subscription */
+};
+
 /*** Nagios Event Radio Dispatcher functions ***/
 extern int nerd_init(void);
 extern int nerd_mkchan(const char *name, const char *description, int (*handler)(int, void *), unsigned int callbacks);
@@ -453,6 +462,8 @@ extern int nerd_get_channel_id(const char *chan_name);
 extern objectlist *nerd_get_subscriptions(int chan_id);
 extern int nerd_broadcast(unsigned int chan_id, void *buf, unsigned int len);
 
+#endif
+
 /*** Query Handler functions, types and macros*/
 typedef int (*qh_handler)(int, char *, unsigned int);
 extern int dump_event_stats(int sd);
@@ -548,7 +559,6 @@ void handle_service_flap_detection_disabled(service *);		/* handles the details
 int check_host_check_viability(host *, int, int *, time_t *);
 int adjust_host_check_attempt(host *, int);
 int determine_host_reachability(host *);
-int process_host_check_result(host *, int, char *, int, int, int, unsigned long);
 int perform_on_demand_host_check(host *, int *, int, int, unsigned long);
 int execute_sync_host_check(host *);
 int run_scheduled_host_check(host *, int, double);
@@ -623,6 +633,9 @@ void my_system_sighandler(int);				/* handles timeouts when executing commands v
 char *get_next_string_from_buf(char *buf, int *start_index, int bufsize);
 int compare_strings(char *, char *);                    /* compares two strings for equality */
 char *escape_newlines(char *);
+#ifdef DETECT_RLIMIT_PROBLEM
+void rlimit_problem_detection(int);
+#endif
 /**
  * Unescapes newlines and backslashes in a check result output string read from
  * a source that uses newlines as a delimiter (e.g., files in the checkresults
@@ -656,6 +669,7 @@ int is_daterange_single_day(daterange *);
 time_t calculate_time_from_weekday_of_month(int, int, int, int);	/* calculates midnight time of specific (3rd, last, etc.) weekday of a particular month */
 time_t calculate_time_from_day_of_month(int, int, int);	/* calculates midnight time of specific (1st, last, etc.) day of a particular month */
 void get_next_valid_time(time_t, time_t *, timeperiod *);	/* get the next valid time in a time period */
+time_t reschedule_within_timeperiod(time_t, timeperiod*, time_t);
 time_t get_next_log_rotation_time(void);	     	/* determine the next time to schedule a log rotation */
 int dbuf_init(dbuf *, int);
 int dbuf_free(dbuf *);
