@@ -2,8 +2,6 @@
  *
  * NEBMODS.H - Include file for event broker modules
  *
- * Copyright (c) 2002-2005 Ethan Galstad (egalstad@nagios.org)
- * Last Modified:  11-25-2005
  *
  * License:
  *
@@ -22,27 +20,23 @@
  *
  *****************************************************************************/
 
-#ifndef _NEBMODS_H
-#define _NEBMODS_H
+#ifndef NAGIOS_NEBMODS_H_INCLUDED
+#define NAGIOS_NEBMODS_H_INCLUDED
 
-#include "config.h"
 #include "nebcallbacks.h"
 #include "nebmodules.h"
 
-#ifdef __cplusplus
-extern "C" { 
-#endif
-
+NAGIOS_BEGIN_DECL
 
 /***** MODULE STRUCTURES *****/
 
 /* NEB module callback list struct */
-typedef struct nebcallback_struct{
+typedef struct nebcallback_struct {
 	void            *callback_func;
 	void            *module_handle;
 	int             priority;
 	struct nebcallback_struct *next;
-        }nebcallback;
+	} nebcallback;
 
 
 
@@ -53,18 +47,16 @@ int neb_deinit_modules(void);
 int neb_load_all_modules(void);
 int neb_load_module(nebmodule *);
 int neb_free_module_list(void);
-int neb_unload_all_modules(int,int);
-int neb_unload_module(nebmodule *,int,int);
-int neb_add_module(char *,char *,int);
+int neb_unload_all_modules(int, int);
+int neb_unload_module(nebmodule *, int, int);
+int neb_add_module(char *, char *, int);
+int neb_add_core_module(nebmodule *mod);
 
 
 /***** CALLBACK FUNCTIONS *****/
 int neb_init_callback_list(void);
 int neb_free_callback_list(void);
-int neb_make_callbacks(int,void *);
-
-#ifdef __cplusplus
-}
-#endif
+int neb_make_callbacks(int, void *);
 
+NAGIOS_END_DECL
 #endif
