@@ -2,8 +2,6 @@
  *
  * PERFDATA.H - Include file for performance data routines
  *
- * Copyright (c) 2001-2005 Ethan Galstad (egalstad@nagios.org)
- * Last Modified:   11-25-2005
  *
  * License:
  *
@@ -22,23 +20,19 @@
  *
  *****************************************************************************/
 
-#ifndef _PERFDATA_H
-#define _PERFDATA_H
+#ifndef NAGIOS_PERFDATA_H_INCLUDED
+#define NAGIOS_PERFDATA_H_INCLUDED
 
+#include "common.h"
 #include "objects.h"
 
-#ifdef __cplusplus
-  extern "C" {
-#endif
+NAGIOS_BEGIN_DECL
 
-int initialize_performance_data(char *);	                /* initializes performance data */
-int cleanup_performance_data(char *);                           /* cleans up performance data */
+int initialize_performance_data(const char *);    /* initializes performance data */
+int cleanup_performance_data(void);               /* cleans up performance data */
 
-int update_host_performance_data(host *);       	        /* updates host performance data */
-int update_service_performance_data(service *);         	/* updates service performance data */
+int update_host_performance_data(host *);         /* updates host performance data */
+int update_service_performance_data(service *);   /* updates service performance data */
 
-#ifdef __cplusplus
-  }
-#endif
-
+NAGIOS_END_DECL
 #endif
