@@ -1,4 +1,3 @@
-/* Stub functions for lib/nsock.c */
 static inline int nsock_vprintf(int sd, const char *fmt, va_list ap, int plus)
 {
 	char buf[4096];
@@ -6,8 +5,10 @@ static inline int nsock_vprintf(int sd, const char *fmt, va_list ap, int plus)
 
 	/* -2 to accommodate vsnprintf()'s which don't include nul on overflow */
 	len = vsnprintf(buf, sizeof(buf) - 2, fmt, ap);
-	if (len < 0)
+	if (len < 0) {
 		return len;
+	}
+
 	buf[len] = 0;
 	return len;
 }
@@ -23,7 +24,8 @@ int nsock_printf_nul(int sd, const char *fmt, ...)
 	return ret;
 }
 
-int nsock_printf(int sd, const char *fmt, ...) {
+int nsock_printf(int sd, const char *fmt, ...)
+{
 	va_list ap;
 	int ret;
 
