@@ -38,22 +38,22 @@
 
 #ifdef NSCGI
 #include "../include/cgiutils.h"
-time_t program_start;
-int daemon_mode;
-time_t last_log_rotation;
-int enable_notifications;
-int execute_service_checks;
-int accept_passive_service_checks;
-int execute_host_checks;
-int accept_passive_host_checks;
-int enable_event_handlers;
-int obsess_over_services;
-int obsess_over_hosts;
+extern time_t program_start;
+extern int daemon_mode;
+extern time_t last_log_rotation;
+extern int enable_notifications;
+extern int execute_service_checks;
+extern int accept_passive_service_checks;
+extern int execute_host_checks;
+extern int accept_passive_host_checks;
+extern int enable_event_handlers;
+extern int obsess_over_services;
+extern int obsess_over_hosts;
 int check_service_freshness;
 int check_host_freshness;
-int enable_flap_detection;
-int process_performance_data;
-int nagios_pid;
+extern int enable_flap_detection;
+extern int process_performance_data;
+extern int nagios_pid;
 int buffer_stats[1][3];
 int program_stats[MAX_CHECK_STATS_TYPES][3];
 #endif
